
Defuse Division
===============

Defuse Division is a real-time competitive multiplayer implementation of the
game Minesweeper that you can play in your terminal. Defuse Division is written
entirely in Python3.

![Can you believe it?](./defusedivision_uiexample00.gif)

## Install with Pip

To install and play, run:

    pip install defusedivision
    defusedivision # Starts the game

## Play from source

Alternatively, you can clone this repository and run the `play-defusedivision`
file in this repository (which works in the same way as the `defusedivision`
command which is installed when you install via pip):

    git clone "https://github.com/lelandbatey/defuse_division"
    cd defuse_division
    ./play-defusedivision


